/***************************************************************************\
 * Micro DVD Menu Maker by Christophe.Paris@free.fr                        *
 ***************************************************************************
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
\***************************************************************************/

// -----------------------------------------------------------------------
#ifndef _PAGE_H_
#define _PAGE_H_

#include "Selection.h"

#include <vector>

using namespace std;

// -----------------------------------------------------------------------

class   Page
{
public:
  Page (int number, AnsiString name, TPicture * Image):Number (number),
    Name (name)
  {
    _SmallImage = new TPicture ();
    _SmallImage->Assign (Image);

    FirstFrameNumber = 0;
    LastFrameNumber = 0;

    PictureDuration = 0;
    JumpAtEnd = 0;
    ProhibitSelectionBefore = 0;
    ProhibitSelectionAfter = 0;
		ColumnOrdering = false;
		SelectionNumber = 0;

    ActionAtEnd = NULL;
  }

         ~Page ()
  {
    delete  _SmallImage;
		for (vector < Selection * >::iterator i = vectSel.begin ();
			i != vectSel.end (); ++i)
		{
			delete (*i);
		}
		if (ActionAtEnd != NULL)
			delete  ActionAtEnd;
	}

  TPicture *GetSmallImage ()
  {
    return _SmallImage;
  }
  void    SetSmallImage (TPicture * pict)
  {
    _SmallImage->Assign (pict);
  }

  operator AnsiString () const
  {
		if (isVideoType)
		{
			return AnsiString (Number) + ") " + Name + " (" + FirstFrameNumber + "-" +
				LastFrameNumber + ")";
		}
		else
		{
			return AnsiString (Number) + ") " + Name;
		}
  }

  AnsiString GetShortName ()
	{
		return AnsiString (Number) + ") " + Name;
	}

	void    ShowSelections (bool show, RShape * model, TControl * AOwner)
	{
		for (vector < Selection * >::iterator i = vectSel.begin ();
			i != vectSel.end (); ++i)
		{
			(*i)->ShowSelection (show, model, AOwner);
		}
	}

	int    GetNumChapters(void)
	{
		// Calculate total number of chapter on this page
		int NumChapters = 0;
		Selection *s;
		MenuAction* ma;

		for (vector < Selection * >::iterator i = vectSel.begin ();
			i != vectSel.end (); ++i)
		{
			s = (*i);
			for(unsigned int i = 0; i < s->vectAction.size() ; ++i )
			{
				ma = s->vectAction[i];
				if( (ma->type - 1) == PLAY_CHAPTER)
					NumChapters++;
			}
		}
		return NumChapters;
	}

	void    CopySelectionsTo (Page * p)
	{
		int nChapter = GetNumChapters();

		for (vector < Selection * >::iterator i = vectSel.begin ();
			i != vectSel.end (); ++i)
		{
			p->vectSel.push_back (new Selection (**i, nChapter));
    }
  }

public:
  int     Number;
  AnsiString Name;
  bool    isVideoType;
  AnsiString PictureFileName;
  bool    SelectionAvailable;
  bool    VideoLoop;
  int     FirstFrameNumber;
  int     LastFrameNumber;

  int     PictureDuration;	// in seconds

  int     JumpAtEnd;		// page number

  int     ProhibitSelectionBefore;	// Frame number
  int     ProhibitSelectionAfter;	// Frame number
  int     DefaultSelection;	// Selection number

	int     SelectionNumber;
	bool		ColumnOrdering;

  vector < Selection * >vectSel;
  MenuAction *ActionAtEnd;

protected:
  TPicture * _SmallImage;
};

// -----------------------------------------------------------------------
#endif
// -----------------------------------------------------------------------
