/***************************************************************************\
 * Micro DVD Menu Maker by Christophe.Paris@free.fr                        *
 ***************************************************************************
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
\***************************************************************************/

// -----------------------------------------------------------------------
#ifndef _SELECTION_H_
#define _SELECTION_H_

#include "Action.h"
#include "RShape.h"
#include <vector>

using namespace std;

// -----------------------------------------------------------------------

class Selection
{
	public:
		Selection(AnsiString _Area, AnsiString _Name, RShape* shape) : Area(_Area) , Name(_Name), shape(shape)
		{
			static int cpt = 0;
			if(_Name.IsEmpty())
				Name = AnsiString("Sel-") + (cpt++);
			shape = NULL;
		}

		Selection(Selection& s)
		{
			this->Name = s.Name;
			this->Area = s.Area;

			for(unsigned int i = 0; i < s.vectAction.size() ; ++i )
				this->vectAction.push_back( new MenuAction( *s.vectAction[i] ) );

			shape = NULL;
		}

		Selection(Selection& s, int offsetChapter)
		{
			this->Name = s.Name;
			this->Area = s.Area;

			for(unsigned int i = 0; i < s.vectAction.size() ; ++i )
			{
				MenuAction * maSrc = s.vectAction[i];
				MenuAction * maDst = new MenuAction( *maSrc );

				if( (maSrc->type - 1) == PLAY_CHAPTER)
					maDst->param = AnsiString(maDst->param.ToInt() + offsetChapter);

				this->vectAction.push_back( maDst );
			}

			shape = NULL;
		}


		void ShowSelection(bool show, RShape* model, TControl* AOwner)
		{
			if(show)
			{
				// Create shape from area x1,y1-x2,y2
				shape = new RShape(model->Parent);
				shape->OnContextPopup = model->OnContextPopup;
				shape->OnChangedSize = model->OnChangedSize;
				shape->OnAnyAnchorMove = model->OnAnyAnchorMove;
				shape->OnMouseDown = model->OnMouseDown;
				shape->OnMouseMove = model->OnMouseMove;
				shape->OnMouseUp = model->OnMouseUp;
				shape->Pen->Color = model->Pen->Color;
				shape->Pen->Mode = model->Pen->Mode;
				shape->Parent = model->Parent;

				int x1,y1,x2,y2;
				sscanf(Area.c_str(),"%d,%d-%d,%d",&x1,&y1,&x2,&y2);

				shape->Top = y1 + AOwner->Top;
				shape->Left = x1 + AOwner->Left;
				shape->Width = x2 - x1;
				shape->Height = y2 - y1;

				shape->Tag = (int)this;
			}
			else if(shape != NULL)
			{
				shape->Parent = NULL;
				delete shape;
				shape = NULL;
			}
		}

		~Selection()
		{
			for (vector<MenuAction*>::iterator i = vectAction.begin();
				i != vectAction.end(); ++i)
			{
				delete (*i);
			}
			if( shape != NULL )
			{
				shape->Parent = NULL;
				delete shape;
			}
		}

		AnsiString GetActionTypeString()
		{
			AnsiString result="";
			vector<MenuAction*>::iterator i = vectAction.begin();

			if( i != vectAction.end() )
			{
				result += AnsiString( (*i)->GetRealType() );
				++i;
			}

			while( i != vectAction.end() )
			{
				result += ( "#" + AnsiString( (*i)->GetRealType() ) );
				++i;
			}

			return result;
		}

		AnsiString GetActionParamString()
		{
			AnsiString result="";
			vector<MenuAction*>::iterator i = vectAction.begin();

			if( i != vectAction.end() )
			{
				result += AnsiString( (*i)->param );
				++i;
			}

			while( i != vectAction.end() )
			{
				result += ( "#" + AnsiString( (*i)->param ) );
				++i;
			}

			return result;
		}

	AnsiString Name;
	AnsiString Area;  // "left,top-right,bottom"
	vector<MenuAction *> vectAction;
	RShape* shape;

};

// -----------------------------------------------------------------------
#endif
// -----------------------------------------------------------------------
